@@ -176,13 +176,23 @@ def test_fqdnurl():
     } == convert(vol.Schema(vol.All(vol.FqdnUrl, str)))
 
 
+def test_maybe():
+    assert {
+        "type": "string",
+        "allow_none": True,
+    } == convert(vol.Schema(vol.Maybe(str)))
+
+
 def test_custom_serializer():
     def custem_serializer(schema):
         if schema is str:
             return {"type": "a string!"}
         return UNSUPPORTED
 
-    assert {"type": "a string!", "upper": True,} == convert(
+    assert {
+        "type": "a string!",
+        "upper": True,
+    } == convert(
         vol.Schema(vol.All(vol.Upper, str)), custom_serializer=custem_serializer
     )
 
